local flower={}
flower.effect = love.graphics.newPixelEffect[[

//#define PETALS

extern number time;
extern vec2 mouse;
extern vec2 screen;

number blur			= 0.0025;
//number pi			= atan(1.0)*4.;
number circleSize	= 0.2;

struct Circle
	{
	vec2 pos;
	number r;
	};

vec2 cnorm(vec2 v)
	{
	return v/max(abs(v.x),abs(v.y));
	}

number Process( Circle g, vec2 p )
	{
	p -= g.pos;
	number an = atan( p.x,p.y );
	number ra = length( p );

	vec2 cs = vec2( cos(an), sin(an) );
	cs = cnorm( cs );

	return
		smoothstep(0.005, 0.001, distance(p, vec2(0., 0.)))*smoothstep(g.r+blur,g.r,ra)+
		smoothstep(0.02, 0.75, distance(p, vec2(0., 0.)))*smoothstep(g.r+blur,g.r,ra);
	}

vec2 rotate(vec2 p, number speed)
	{
	return vec2(cos(speed) * p.x + sin(speed) * p.y, -sin(speed) * p.x + cos(speed) *p.y);
	}

vec3 flower(number rx, number ry, vec2 p)
	{
	vec3 c = vec3(0.0);

	Circle g0 = Circle(vec2(rx,ry),circleSize);
	Circle g1 = Circle(vec2(rx,ry+0.202),circleSize);
	Circle g2 = Circle(vec2(rx,ry-0.202),circleSize);
	Circle g3 = Circle(vec2(rx-0.175,ry+0.101),circleSize);
	Circle g4 = Circle(vec2(rx+0.175,ry+0.101),circleSize);
	Circle g5 = Circle(vec2(rx-0.175,ry-0.101),circleSize);
	Circle g6 = Circle(vec2(rx+0.175,ry-0.101),circleSize);

	c =  Process(g0,p)*vec3(0.8,0.,0.);
	c += Process(g1,p)*vec3(1.,1.,0.);
	c += Process(g2,p)*vec3(1.,0.,1.);
	c += Process(g3,p)*vec3(0.,0.,1.);
	c += Process(g4,p)*vec3(0.4,0.7,.2);
	c += Process(g5,p)*vec3(0.,1.,1.);
	c += Process(g6,p)*vec3(0.,0.42,0.45);

	#ifdef PETALS
	Circle g7 = Circle(vec2(rx+0.345,ry-0.202),circleSize);
	Circle g8 = Circle(vec2(rx-0.345,ry-0.202),circleSize);
	Circle g9 = Circle(vec2(rx+0.345,ry+0.202),circleSize);
	Circle g10= Circle(vec2(rx-0.345,ry+0.202),circleSize);
	Circle g11= Circle(vec2(rx,ry+0.404),circleSize);
	Circle g12= Circle(vec2(rx,ry-0.404),circleSize);
	Circle g13 = Circle(vec2(rx,ry),circleSize*2.);

	c += Process(g7,p)*vec3(0.125);
	c += Process(g8,p)*vec3(0.125);
	c += Process(g9,p)*vec3(0.125);
	c += Process(g10,p)*vec3(0.125);
	c += Process(g11,p)*vec3(0.125);
	c += Process(g12,p)*vec3(0.125);
	#endif

	return c;
	}

vec4 effect( vec4 color, Image tex, vec2 tc, vec2 pc )
	{
	number speed = time * ( 0.5 + sin( time * 0.1)*0.06);

	vec2 res = vec2( 2.66*mouse.x,2.*mouse.y);
	vec2 p = ( pc.xy / screen.y ) - ( res / 2. );

	number radiusX  = p.x / screen.x;
	number radiusY  = p.y / screen.y;

	number a = atan( p.x, p.y ) + time;
	number r = length( p );

	vec3 c = vec3( 0.001 );

	// recursion & spinage
	c += flower( radiusX, radiusY, p );
	c += flower( radiusX, radiusY, rotate( p, -speed ) );
	c += flower( radiusX, radiusY, rotate( p, speed ) );

	speed += sin( time );
	c += flower( radiusX, radiusY, rotate(p/1.5, -speed/2.0 ) );
	c += flower( radiusX, radiusY, rotate(p/1.5,  speed/2.0 ) );

	return vec4( vec3( c ), 1.0 );
	}
]]

return flower
